@@ -1,7 +1,7 @@
 #  ComparableUserId.pm
 #    - providing an object-oriented approach to GnuPG user ids
 #
-#  Copyright (C) 2000 Frank J. Tobin <ftobin@cpan.org>
+#  Copyright (C) 2000 Frank J. Tobin <ftobin@uiuc.edu>
 #
 #  This module is free software; you can redistribute it and/or modify it
 #  under the same terms as Perl itself.
@@ -10,14 +10,16 @@
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
 #  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 #
-#  $Id: ComparableUserId.pm,v 1.3 2001/09/14 12:34:36 ftobin Exp $
+#  $Id: ComparableUserId.pm,v 1.1 2001/04/28 04:01:04 ftobin Exp $
 #
 
 package GnuPG::ComparableUserId;
 
 use strict;
+use vars qw( @ISA );
+use GnuPG::UserId;
 
-use base qw( GnuPG::UserId );
+push @ISA, 'GnuPG::UserId';
 
 sub compare
 {
@@ -42,20 +44,14 @@ sub _deeply_compare
     return 0 unless @self_signatures == @other_signatures;
     
     my $num_sigs = @self_signatures;
-    my $i;
     
-    for ( $i = 0; $i < $num_sigs; $i++ )
+    for ( my $i = 0; $i < $num_sigs; $i++ )
     {
+	
 	return 0
 	  unless $self_signatures[$i]->compare( $other_signatures[$i], 1 );
     }
-
-    # FIXME: what if the other item has revocations that we don't have?
-    for ( $i = 0; $i < scalar(@{$self->revocations}); $i++ ) {
-      return 0
-        unless $self->revocations()->[$i]->compare($other->revocations()->[$i], 1);
-    }
-
+    
     return 1;
 }
 
